@@ -31,7 +31,7 @@ def connect(port=8095):
         return result
 
 def exit():
-    """Exiting the connection
+    """Exiting the connection. Also clears automation mode
 
     """
     automationMode(False)
@@ -48,7 +48,12 @@ def getClient():
     return client
 
 def call(procedure,arguments):
-    """Support manually calling a procedure with args
+    """Support manually calling a waapi procedure with custom arguments
+
+    :param procedure: The name of the waapi procedure to call
+    :param arguments: The argument map to pass to procedure
+
+    :return: Result structure or False
 
     """
     try:
@@ -85,8 +90,8 @@ def cancelUndoGroup():
 
 def endUndoGroup(undogroup):
     """Name and end an undo group
-    args:
-    undogroup -- Name to give the undo group that is ending
+
+    :param undogroup: Name to give the undo group that is ending
 
     """
     undoArgs = {"displayName": undogroup}
@@ -107,7 +112,11 @@ def saveWwiseProject():
         return False
 
 def setupSubscription(subscription, target, returnArgs = ["id", "name", "path"]):
-    """Subscribe to an event. Do target when triggered, get retunArgs in
+    """Subscribe to an event. Define a target to call when triggered, get the retunArgs back
+
+    :param subscription: Waapi subscription topic
+    :param target: The function to run on the callback trigger
+    :param returnArgs: Properties to return with the callback
 
     """
     try:
@@ -116,15 +125,14 @@ def setupSubscription(subscription, target, returnArgs = ["id", "name", "path"])
         print("call error: {}".format(ex))
         return False
 
-def getProjectInfo():
-    """Get the wwise project info
-    e.g. filePath, @DefaultLanguage
+def getProjectInfo(ret=[]):
+    """Get the wwise project info by default returns filePath, @DefaultLanguage
 
     """
     arguments = {
         "from": {"ofType": ["Project"]},
         "options": {
-            "return": ["type","id", "name", "filePath","@DefaultLanguage"]
+            "return": ["type","id", "name", "filePath","@DefaultLanguage"]+ret
         }
     }
     try:
@@ -167,20 +175,17 @@ def getPathToWwiseProjectFolder():
     pathToWwiseFolder = os.path.expanduser(os.path.dirname(WwiseProjectPath))
     return pathToWwiseFolder
 
+
 ###  Object creation and property setting ######
-
-
 def createWwiseObject(parentID, otype="BlendContainer", oname="", conflict="merge"):
     """Create a wwise object of type otype, called oname, underneath
 
-    args:
-    parentID -- The GUID of the parent object
-    otype -- The type of wwise object to create
-    oname -- The name to give the new object
-    conflict -- Behaviour for conflicting objects (default=merge)
+    :param parentID: The GUID of the parent object
+    :param otype: The type of wwise object to create
+    :param oname: The name to give the new object
+    :param conflict: Behaviour for conflicting objects (default=merge)
 
-    returns:
-    The newly created wwise object structure or False
+    :return: The newly created wwise object structure or False
 
     """
     createObjArgs = {
@@ -201,11 +206,8 @@ def createWwiseObjectFromArgs(args = {}):
     """Create a wwise object from a custom argument structure.
     Useful if you need to create many complex objects.
 
-    args:
-    args{} -- A map of custom arguments for ak.wwise.core.object.create
-
-    returns:
-    The newly created wwise object(s) or False
+    :param args: A map of custom arguments for ak.wwise.core.object.create
+    :return: The newly created wwise object(s) or False
 
     """
     try:
@@ -219,13 +221,10 @@ def createWwiseObjectFromArgs(args = {}):
 def setProperty(object, property, value):
     """Set a property of a wwise object
 
-    args;
-    object -- GUID of the object
-    property -- Name of the property to set
-    value -- The value to set for given property
-
-    returns:
-    The result of the operation
+    :param object: GUID of the object
+    :param property: Name of the property to set
+    :param value: The value to set for given property
+    :return: Result structure or False
 
     """
     setPropertyArgs = {
@@ -244,13 +243,10 @@ def setProperty(object, property, value):
 def setReference(object, reference, value):
     """Set a reference of a wwise object
 
-    args;
-    object -- GUID of the object
-    reference -- Name of the reference to set
-    value -- The value to set for given property
-
-    returns:
-    The result of the operation
+    :param object: GUID of the object
+    :param reference: Name of the reference to set
+    :param value: The value to set for given property
+    :return: Result structure or False
 
     """
     setArgs = {
@@ -269,9 +265,9 @@ def setReference(object, reference, value):
 def setNotes(object, value):
     """Set the notes of object to value
 
-    args:
-    object -- GUID of the object
-    value -- String to set as notes
+    :param object: GUID of the object
+    :param value: String to set as notes
+    :return: Result structure or False
 
     """
     setPropertyArgs = {
@@ -288,11 +284,9 @@ def setNotes(object, value):
 
 def importAudioFiles(args):
     """Import audio files with custom args
-    args:
-    args{} -- A map of custom arguments for ak.wwise.core.audio.import
 
-    returns:
-    The newly created imported object(s) or False
+    :param args: A map of custom arguments for ak.wwise.core.audio.import
+    :return: Result structure or False
 
     """
     try:
@@ -306,14 +300,11 @@ def importAudioFiles(args):
 def setupImportArgs(parentID, fileList,originalsPath,language="SFX"):
     """Helper function to construct args for import operation
 
-    args:
-    parentID -- GUID of the parent object
-    fileList -- List of audio files to import
-    originalsPath -- Relative location to put new files inside Originals
-    language -- Import audio as SFX (default) or a given language
-
-    returns:
-    An arguments structure that can be used with importAudioFiles()
+    :param parentID: GUID of the parent object
+    :param fileList: List of audio files to import
+    :param originalsPath: Relative location to put new files inside Originals
+    :param language: Import audio as SFX (default) or a given language
+    :return: Result structure or False
 
     """
     ParentID = str(parentID)
@@ -344,8 +335,8 @@ def setupImportArgs(parentID, fileList,originalsPath,language="SFX"):
 def deleteWwiseObject(object):
     """Delete a wwise object
 
-    args:
-    object -- GUID of object to be deleted
+    :param object: GUID of object to be deleted
+    :return: Result structure or False
 
     """
     args = {"object":object}
@@ -360,12 +351,9 @@ def deleteWwiseObject(object):
 def getSelectedObjects(properties=[]):
     """Get the currently selected object(s), returning any extra properties
 
-    args:
-    properties[] -- list of additional properties to be returned for the wwise objects.
+    :param properties: list of additional properties to be returned for the wwise objects.
     by default objects will return ["id","type", "name", "path"] + properties[]
-
-    returns:
-    List of currently selected wwise objects or False
+    :return: Result structure or False
 
     """
     baseProperties = ["id","type", "name", "path"]
@@ -388,17 +376,16 @@ def getSelectedObjects(properties=[]):
 def getDescendantObjectsOfType(fromObject,ofType,returnProperties=[],tfrom="id",select="descendants"):
     """Perform a search fromObject to find descendants ofType, return additional properties for each object.
     Optionally change the from and select parts of the query, by default use ID as the object
-
-    args:
-    fromObject -- starting point of search. Default is a GUID
-    ofType -- Type of wwise objects to search for
-    returnProperties -- Additional properties to return for each object
-    tfrom -- Key that determines how fromObject is used in the search (default=id)
-    select -- Key that determines which objects are searched in relation to the fromObject (default=descendants)
-
     for more info on options see Wwise SDK for ak.wwise.core.object.get
     https://www.audiokinetic.com/library/edge/?source=SDK&id=ak_wwise_core_object_get.html
 
+    :param fromObject: Starting point of search. Default is a GUID
+    :param ofType: Type of wwise objects to search for
+    :param returnProperties: Additional properties to return for each object
+    :param tfrom: Key that determines how fromObject is used in the search (default=id)
+    :param select: Key that determines which objects are searched in relation to the fromObject (default=descendants)
+    :return: Result structure or False
+
     """
     baseProperties = ["id","type", "name", "path"]
     arguments = {
@@ -426,11 +413,11 @@ def getDescendantObjects(fromObject,returnProperties=[],tfrom="id",select="desce
     """Perform a search fromObject to find all descendants, return additional properties for each object.
     Optionally change the from and select parts of the query, by default use ID as the object
 
-    args:
-    fromObject -- starting point of search. Default is a GUID
-    returnProperties -- Additional properties to return for each object
-    tfrom -- Key that determines how fromObject is used in the search (default=id)
-    select -- Key that determines which objects are searched in relation to the fromObject (default=descendants)
+    :param fromObject: Starting point of search.
+    :param returnProperties: Additional properties to return for each object
+    :param tfrom: Key that determines how fromObject is used in the search (default=id)
+    :param select: Key that determines which objects are searched in relation to the fromObject (default=descendants)
+    :return: Result structure or False
 
     for more info on options see Wwise SDK for ak.wwise.core.object.get
     https://www.audiokinetic.com/library/edge/?source=SDK&id=ak_wwise_core_object_get.html
@@ -462,11 +449,11 @@ def getObjectsByName(name,type,returnProperties=[],tfrom="ofType"):
     """Perform a search by name, return additional properties for each object.
     Named search must also include a type filter
 
-    args:
-    name -- String to match with object names
-    type -- Type of wwise objects to search for
-    returnProperties -- Additional properties to return for each object
-    tfrom -- Key that determines how fromObject is used in the search (default=ofType)
+    :param name: String to match with object names
+    :param type: Type of wwise objects to search for
+    :param returnProperties: Additional properties to return for each object
+    :param tfrom: Key that determines how fromObject is used in the search (default=ofType)
+    :return: Result structure or False
 
     for more info on options see Wwise SDK for ak.wwise.core.object.get
     https://www.audiokinetic.com/library/edge/?source=SDK&id=ak_wwise_core_object_get.html
@@ -497,11 +484,10 @@ def getObjectsByName(name,type,returnProperties=[],tfrom="ofType"):
 def getObjectProperties(fromObject,returnProperties=[],tfrom="id"):
     """Get some additional properties from a wwise Object, by default use ID as the object
 
-    args:
-    fromObject --  Wwise object to get properties from. Default is a GUID
-    returnProperties -- Additional properties to return for each object
-    tfrom -- Key that determines how fromObject is used in the search (default=id)
-
+    :param fromObject: Wwise object to get properties from. Default is a GUID
+    :param returnProperties: Additional properties to return for each object
+    :param tfrom: Key that determines how fromObject is used in the search (default=id)
+    :return: Result structure or False
     for more info on options see Wwise SDK for ak.wwise.core.object.get
     https://www.audiokinetic.com/library/edge/?source=SDK&id=ak_wwise_core_object_get.html
 
@@ -531,9 +517,9 @@ def getObjectProperties(fromObject,returnProperties=[],tfrom="id"):
 def getAllObjectsOfType(ofType,returnProperties=[]):
     """Get all objects of a certain type, and return any extra properties
 
-    args:
-    ofType -- Type of wwise objects to search for
-    returnProperties -- Additional return properties to get for each object
+    :param ofType: Type of wwise objects to search for
+    :param returnProperties: Additional return properties to get for each object
+    :return: Result structure or False
 
     """
     baseProperties = ["id","type", "name", "path"]
@@ -558,7 +544,14 @@ def getAllObjectsOfType(ofType,returnProperties=[]):
             return []
 
 def getReferencesToObject(objectID,returnProperties=[],tfrom="id"):
-    """ get the references to a given object, by default use ID as the object"""
+    """ get the references to a given object, by default use ID as the object
+
+    :param fromObject: Wwise object to get references to. Default is a GUID
+    :param returnProperties: Additional properties to return for each object
+    :param tfrom: Key that determines how fromObject is used in the search (default=id)
+    :return: Results structure or False
+
+    """
     baseProperties = ["id","type", "name", "path"]
     arguments = {
         "from": {tfrom: [objectID]},
@@ -591,8 +584,14 @@ def getListOfTypes():
         return res
 
 def filterWwiseObjects(objects,property,operation, value, NOT=0):
-    """helper function to filter a list of objects by a specific property, value and comparison operation"""
+    """helper function to filter a list of objects by a specific property, value and comparison operation
     # e.g. return only objects with "@Volume" , "<" , "-48"
+
+    :param objects: List of wwise objects to filter
+    :param property: Which property to filter by
+    :param operation: String comparison operator for filter. One of; "==","<","<=",">",">=","!=","contains"
+    :return: List of objects matching filters
+    """
     results = []
     op = getOperator(operation)
     for obj in objects:
@@ -607,6 +606,7 @@ def filterWwiseObjects(objects,property,operation, value, NOT=0):
     return results
 
 def getOperator(string):
+    """Helper function to convert string comparison to python operator"""
     if string == "==":
         return operator.eq
     elif string == "<":
@@ -628,6 +628,9 @@ def getOperator(string):
 
 #####  Soundbanks #####
 def generateSoundbanks(banklist = []):
+    """Generate soundbanks
+    :param banklist: List of bank names to generate
+    """
     args = {
         "command": "GenerateSelectedSoundbanksAllPlatforms",
         "objects": [
@@ -640,12 +643,16 @@ def generateSoundbanks(banklist = []):
         print("call error: {}".format(ex))
         return False
 
-def getSoundbanks(fromType,fromValue):
-    """ Return all Soundbanks referencing any object of the Work Unit directly"""
+def getSoundbanks(tfrom,obj):
+    """ Return all Soundbanks referencing any object of the Work Unit directly
+    :param tfrom: Key that determines how obj is used in the search (default=id)
+    :param obj: The object to use in the search
+    :return: List of banks directly referencing obj
+    """
     BankList =[]
-    for transform in bankhelper.bankTransforms:
+    for transform in soundbank_helper.bankTransforms:
         arguments = {
-            "from": {fromType: [fromValue]},
+            "from": {tfrom: [obj]},
             "transform": transform,
             "options": {
                 "return": ['id', 'name', 'type']
@@ -665,7 +672,13 @@ def getSoundbanks(fromType,fromValue):
 
 
 def executeCommand(command,objects = []):
-    """wrapper to execute UI commands"""
+    """wrapper to execute UI commands
+    See https://www.audiokinetic.com/library/2017.1.9_6501/?source=SDK&id=globalcommandsids.html
+
+    :param command: Command to execute
+    :param objects: List of objects to pass to the command
+    :return: Result structure or False
+    """
     args = {
         "command": command,
         "objects": [
@@ -685,7 +698,7 @@ def automationMode(enabled):
 
     :param enabled: True or False
 
-    :return: Result
+    :return: Result struct or False
 
     """
     args = {
@@ -700,16 +713,26 @@ def automationMode(enabled):
         return res
 
 def checkoutWorkUnit(workunitID):
-    """Source control operation to check out work unit"""
+    """Source control operation to check out work unit
+    :param workunitID: GUID of the work unit to checkout
+    :return: Result structure or False
+    """
     return executeCommand("WorkgroupCheckoutWWU",workunitID)
 
 def cleanfilePathFromWwise(path):
-    """Cleans the nonsense from Mac paths that Wwise gives you"""
+    """Cleans the undesired characters from Mac paths that Wwise gives you
+    :param path: path to clean (e.g. wproj or work unit path)
+    :return: Cleaned path
+    """
     cleanMacpath = path.replace("Y:","~").replace('\\', '/')
     return os.path.abspath(os.path.expanduser(cleanMacpath))
 
 def setSwitchContainerAssignment(switch,child):
-    """Assign a given child object to a given switch (switch container)"""
+    """Assign a given child object to a given switch (switch container)
+    :param switch: Name of the switch to assign child to
+    :param child: ID of the wwise object to assign to switch
+    :return: Result structure or False
+    """
     args = {
         "stateOrSwitch": switch,
         "child":child
@@ -723,7 +746,11 @@ def setSwitchContainerAssignment(switch,child):
         return res
 
 def removeSwitchContainerAssignment(switch,child):
-    """Remove a given child object from a given switch (switch container)"""
+    """Remove a given child object from a given switch (switch container)
+    :param switch: Name of the switch to assign child to
+    :param child: ID of the wwise object to assign to switch
+    :return: Result structure or False
+    """
     args = {
         "stateOrSwitch": switch,
         "child":child
@@ -737,7 +764,13 @@ def removeSwitchContainerAssignment(switch,child):
         return res
 
 def moveWwiseObject(object,parent, conflict="replace"):
-    """move object to new location under parent"""
+    """move object to new location under parent
+    :param object: ID of wwise object to move
+    :param parent: ID of the parent to move object under
+    :param conflict: Behaviour for conflicting objects (default = replace)
+    :return: Result structure or False
+
+    """
     args = {
 
         "object": object,
@@ -753,7 +786,12 @@ def moveWwiseObject(object,parent, conflict="replace"):
         return res
 
 def copyWwiseObject(object, parent, conflict="replace"):
-    """copy object to new location under parent"""
+    """copy object to new location under parent
+    :param object: ID of wwise object to copy
+    :param parent: ID of the parent to paste object under
+    :param conflict: Behaviour for conflicting objects (default = replace)
+    :return: Result structure or False
+    """
     args = {
 
         "object": object,
